#
# Quasi-geostationary constellation
#
# three-satellite inclined geosynchnronous system.
# Researched for Japan - covers high latitudes while allowing a high mask.
#
# This simulation is intended to match what is described in:
# T. Taleb, U. Dharmaratna, N. Kato, and Y. Nemoto, A Geographical Location
# Based Satellite Selection Scheme for a Novel Constellation Composed of
# Quasi-Geostationary Satellites, Proceedings of IEEE International Conference
# on Communication, ICC 2005, Seoul, Korea, May 2005.
# http://dx.doi.org/10.1109/ICC.2005.1494588
#
# See also:
# T. Taleb, A. Jamalipour, N. Kato, and Y. Nemoto, A Theatre in the Sky:
# A Ubiquitous Broadband Multimedia-on-Demand Service over a Novel
# Constellation Composed of Quasi-Geostationary Satellites, International
# Journal of Satellite Commununications and Networking, Vol. 24, No. 3,
# May/June 2006. pp. 215-227.
# http://doi.wiley.com/10.1002/sat.829
#
# T. Taleb, Internetworking over Next-Generation NGEO/IP-based Satellite
# Communications Systems, PhD thesis, Tohoku University, August 2005.
# See chapter 6.
# http://www.nemoto.ecei.tohoku.ac.jp/%7Etaleb/Library/phd_thesis.pdf
#
# this script for SaVi 1.2, by Lloyd Wood (lloydwood@users.sourceforge.net)
# http://savi.sourceforge.net/
#
# $Id: quasi-geo.tcl,v 1.5 2008/03/06 01:07:27 lloydwood Exp $


# Draw single plane over Japan for illustrative purposes.
# To see global coverage as described in Taleb's work, set this to 6.
set NUM_PLANES 1

# Set location of one triple system; the others will be spaced from it.
# East is positive. Taleb gives 118 for East Asia in Fig 6.2 of his thesis;
# we use 140 to also cover Australia/New Zealand, so that the southern
# hemisphere coverage is useful as well.
set desired_longitude 140

set SATS_PER_PLANE 3

# setup orbital elements
set a [expr 35786.1+$RADIUS_OF_EARTH]
set e 0.0
set inc 45.0
set omega 0.0
set Omega 0.0
set T_per [expr 2 * $PI * pow($a,1.5) / sqrt($MU)]

# Presume high-frequency Ka-band use
set coverage_angle 40.0

set offset_between_planes [expr 360.0 / $NUM_PLANES ]

satellites GV_BEGIN

for {set i 0} {$i < $NUM_PLANES} {incr i} {

    set sat_longitude [expr $desired_longitude + $i * $offset_between_planes]

    for {set j 0} {$j < $SATS_PER_PLANE} {incr j} {
	# SaVi handles wraparound beyond +/-180
	set Omega [ expr 360.0/$SATS_PER_PLANE * $j + $sat_longitude]
	set T [expr $T_per / 3 * $j]
	satellites LOAD $a $e $inc $Omega $omega $T "Quasi-GEO-$j"
    }

}

satellites GV_END
