#
# Teledesic
#
# Original Calling 840-active-satellite design.
# In reality, maintaining phasing between planes for all these
# satellites would be impossible, making phasing random.
# perfect simulations neglect that, optimising phasing.
#
# $Id: teledesic-840.tcl,v 1.4 2006/09/30 00:46:24 lloydwood Exp $

set SATS_PER_PLANE 40
set NUM_PLANES 21
set INTERPLANE_SPACING 9.5

# setup orbital elements
set a [expr 750.0+$RADIUS_OF_EARTH]
set e 0.00118
set inc 98.7
set omega 0.0

# Ka-band and 40 degrees mask elevation.
set coverage_angle 40.0

# compute period of orbit
set T_per [expr 2 * $PI * pow($a,1.5) / sqrt($MU)]

satellites GV_BEGIN
for {set j 0} {$j < $NUM_PLANES} {incr j} {

	# space planes evenly so that intersection with the
	# equatorial plane are separated by INTERPLANE_SPACING.
	set Omega [expr $j * $INTERPLANE_SPACING]

	# put planes at different heights
	set a_plane [expr $a+0.5*$j]

	for {set i 0} {$i < $SATS_PER_PLANE} {incr i} {
		set T [expr $T_per * ($i + $j/double($NUM_PLANES)) / \
			$SATS_PER_PLANE ]
		set n [satellites LOAD $a_plane $e $inc $Omega $omega $T "Teledesic-1994 ($i, $j)"]
		# only display one orbit in each plane
		if {$i > 0} {satellites ORBIT_SET $n 0}
	}
}
satellites GV_END
